rm(list=ls())

#This is the R script used to analyze the corpus data from Russian Sign Language, as reported in:
#Kimmelman, V. (2016) Transitivity in RSL: a corpus-based account. In E. Efthimiou, S-E. Fotinea, T. Hanke, J. Hochgesang, J. Kristoffersen, & J. Mesch (Eds.), Proceedings of the 7th Workshop on the representation and processing of Sign Languages: Corpus Mining (pp. 117-120). ELRA.
#Please see this paper for all the details.

#The script uses the following files: 
#1. RSLverbsF.txt - the main file with the data exported from ELAN and cleaned up in advance
#2. hierarchies.txt - derived from the main data file + additional data from Haspelmath (2015), see comments below

#---------------Extracting data about overt arguments-----------------

RSLverbsF <- read.csv("RSLverbsF.txt", sep="\t")
#This is the main dataset
#It contains the following columns: Verb (verbal meaning of the item), BeginTime (where in the file is this item), WO (word order), alternation (whether there is an argument structure alternation); file (file name); city (Moscow or Novosibirsk); and the columbs for overt object, overt indirect object, overt subject, overt clausal object, and overt clausal indirect object

#tabulate overt direct object
OOtable<-table(RSLverbsF$Verb, RSLverbsF$OO); OOtable
propOO<-prop.table(OOtable,1); propOO
OOprop<-sort(propOO[,2]) #how often there is O
OOprop

#plot

#plotting it, without the labels on X, with extra space on Y for future labels
plot(OOprop, xaxt="n", main="Frequent verbs with overt O", ylab="proportion of overt objects", xlab="", ylim=c(0,0.75))
#plotting the labels for verbs with 0.05 space between the dot and the label, with 90% turn, above
text(OOprop+0.05, xaxt="n", labels = names(OOprop), srt = 90, pos = 3)

#indirect objects
OO2table<-table(RSLverbsF$Verb, RSLverbsF$OO2); OO2table
propOO2<-prop.table(OO2table,1); propOO2
OO2prop<-sort(propOO2[,2]) #how often there is O
OO2prop

#plot

#plotting it, without the labels on X, with extra space on Y for future labels
plot(OO2prop, xaxt="n", main="Frequent verbs with overt O2", ylab="proportion of overt indirect objects", xlab="", ylim=c(0,0.4))
#plotting the labels for verbs with 0.05 space between the dot and the label, with 90% turn, above
text(OO2prop+0.05, xaxt="n", labels = names(OO2prop), srt = 90, pos = 3)

#clausal direct and indirect objects combined

#first I created separate tables for overt C and overt C2
OCOtable<-table(RSLverbsF$Verb, RSLverbsF$OCO); OCOtable
OCO2table<-table(RSLverbsF$Verb, RSLverbsF$OCO2); OCO2table
#combine the two tables
allCtable<-cbind(OCOtable,OCO2table)[,c(2,4)]
#sum up overt C and CO2
overtC<-allCtable[,1]+allCtable[,2]
#calculate cases without C or CO2
total<-table(RSLverbsF$Verb)
nonovertC<-total-overtC; nonovertC
#create the table
overtCtable<-cbind(nonovertC, overtC)
overtCtable

propCO<-prop.table(overtCtable,1); propCO
COprop<-sort(propCO[,2]) #how often there is CO or CO2
COprop

#plot

#plotting it, without the labels on X, with extra space on Y for future labels
plot(COprop, xaxt="n", main="Frequent verbs with overt CO", ylab="proportion of clausal compelements", xlab="", ylim=c(0,1.1))
#plotting the labels for verbs with 0.05 space between the dot and the label, with 90% turn, above
text(COprop+0.05, xaxt="n", labels = names(COprop), srt = 90, pos = 3)

OStable<-table(RSLverbsF$Verb, RSLverbsF$OS); OStable
propOS<-prop.table(OStable,1)
propOS
propOS<-sort(propOS[,2])#how often there is an overt subject
plot(propOS, xaxt="n", main="Frequent verbs and overt subjects", ylab="% of overt subjects", xlab="", ylim=c(0,0.75))
text(propOS+0.05, xaxt="n", labels = names(propOS), srt = 90, pos = 3)

#----Correlations between RSL data and typological data-----------

hierarchies <- read.delim("hierarchies.txt")
#This table contains proportions of overt arguments per verb label derived from my dataset and proportions of languages which lexicalize the verbs as transitive in Haspelmath (2015)

#analysis
attach(hierarchies)
cor.test(Haspelmath, OO, method="spearman")
cor.test(Haspelmath, OO, method="kendall")
#high significant correlations, approximation because of ties

cor.test(Haspelmath, OO2, method="spearman")
#low nonsignificant
cor.test(Haspelmath, OS, method="spearman")
#low negative non-significant
cor.test(Haspelmath, OCO, method="spearman")
cor.test(Haspelmath, OCO, method="kendall")
#medium almost significant

detach(hierarchies)




